function [fdist,findex,fi,akvalmat,rkval,ustate]=buttgui...
  (ButtonHndl,SliderAHndl,SliderAVHndl,SliderBHndl,SliderBVHndl,...
   imageAHndl,imageBHndl,UDfa,VEDfa,Rfa,...
   kansen,akvalmat,kvalmat,ukval,rkval,fdist,findex,fi,ustate,buttnum)
%buttgui: Button GUI
%
%          function [fdist,findex,fi,akvalmat,rkval,ustate]=buttgui...
%            (ButtonHndl,SliderAHndl,SliderAVHndl,SliderBHndl,SliderBVHndl,...
%             imageAHndl,imageBHndl,UDfa,VEDfa,Rfa,...
%             kansen,akvalmat,kvalmat,ukval,rkval,fdist,findex,fi,ustate,buttnum)
%
%          Where
%
%          ButtonHndl: Vector of the Button Handles
%          SliderAHndl: Vector of the Working Picture Slider Handles
%          SliderAVHndl: Vector of the Working Picture value Display Slider Handles
%          SliderBHndl: Vector of the Editing Picture Slider Handles
%          SliderBVHndl: Vector of the Editing Picture value Display Slider Handles
%          imageAHndl: Working Image Handle
%          imageBHndl: Editing Image Handle
%          UDfa : Matrix of Universe of Discourses
%                  UDfa = [U1;U2;U3;U4;...;SU1;SU2;SU3;SU4;...;CU1]
%          VEDfa : Matrix of the Vague Environments
%          Rfa : Rulebases for the fuzzy automata (all the same)
%                 (voting for the values of the user states)
%          kansen: enabling the kansei identifiers (1: enable, 0:disable)
%          kvalmat: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%          akvalmat: Is the actual kansei value matrix
%          ukval: Vector of the user kansei values
%          rkval: Vector of the user required kansei values
%          fdist: The vector of normalised furniture distances 
%          findex: Furniture index vector (first is the best fitting)
%          fi: Furniture index pointer
%          ustate: User Type State
%          buttnum: The number of the button pressed 
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=20,error('Invalid number of arguments!');end

kvalnum = size(kvalmat,2);  % number of kansei values
utypenum = size(kvalmat,3);  % number of the user types

switch(buttnum)
  case 1  % the Copy button
    if strcmp(get(ButtonHndl(1),'String'),'Copy')
      drawfpicb(imageBHndl,findex(fi),SliderBVHndl,akvalmat,ustate);  % Copy the working pic
    else
      for i=1 : 1 : kvalnum  % Disabling the Editing Sliders
        if kansen(i)==1  % the kansei feature is valid
          colm = get(SliderBHndl(i),'UserData');  % color matrix
          set(SliderBHndl(i),'Enable','off',...  % disable
            'BackgroundColor',colm(:,:,1));  % set color inactive
        end;  % if
      end;  % for
      set(ButtonHndl(3),'Enable','off');  % disable the Ready button
      set(ButtonHndl(1),'String','Copy');  % change back to the Copy function
    end  % if

  case 2  % not used
    error('Invalid button value!');

  case 3  % the Ready button
    for i=1 : 1 : kvalnum  % Disabling the Editing Sliders
      if kansen(i)==1  % the kansei feature is valid
        colm = get(SliderBHndl(i),'UserData');  % color matrix
        set(SliderBHndl(i),'Enable','off',...  % disable
          'BackgroundColor',colm(:,:,1));  % set color inactive
      end;  % if
    end;  % for
    if isnan(rkval)  % The user requirements data is not valid (do nothing)
    else  % The user requirements data is valid
      fnum = get(imageBHndl,'UserData');  % Editing picture number
      ksim = kanssim(kvalmat,rkval,fnum);  % calculate the kansei similarity
      ustate = kansa(UDfa,VEDfa,Rfa,ustate,ksim);  % calculate the new ustate (fuzzy automat)
      akvalmat = gakansvl(kvalmat,ustate);  % recalc the actual kansei values
      drawfpicb(imageBHndl,get(imageBHndl,'UserData'),...
        SliderBVHndl,akvalmat,ustate);  % adjust the user type
      ofindex = findex;  % save the previous value
      ofi = fi;
      [fdist,findex]=kansdist(akvalmat,ukval);  % new furniture kansei distances and index
      if findex==ofindex  % there are no changes
        fi = ofi;  % do nothing
      else
        fi = 1;  % reset pointer
        set(ButtonHndl(5),'Enable','off');  % disable the Previous button
        set(ButtonHndl(4),'Enable','on');  % enable the Next button
      end  % if
      drawfpica(imageAHndl,fdist,findex,fi,SliderAVHndl,akvalmat);  % Draw the new picture
    end  % if
    set(ButtonHndl(3),'Enable','off');  % disable the Ready button
    set(ButtonHndl(1),'String','Copy');  % change back to the Copy function

  case 4  % the Next button
    if fi<size(findex,1)  % there are more furnitures
      fi = fi+1;  % next furniture
      drawfpica(imageAHndl,fdist,findex,fi,SliderAVHndl,akvalmat);  % Draw the next picture
    end  % if
    if fi==size(findex,1)  % the last
      set(ButtonHndl(4),'Enable','off');  % disable the Next button
    end  % if
    set(ButtonHndl(5),'Enable','on');  % enable the Previous button

  case 5  % the Previous button
    if fi>0  % not the first furniture
      fi = fi-1;  % previous furniture
      drawfpica(imageAHndl,fdist,findex,fi,SliderAVHndl,akvalmat);  % Draw the previous pict.
    end  % if
    if fi==1  % the first
      set(ButtonHndl(5),'Enable','off');  % disable the Previous button
    end  % if
    set(ButtonHndl(4),'Enable','on');  % enable the Next button

  otherwise
    error('Invalid button value!');
end  % switch

