function [fdist,findex,fi,ukval]=chgui...
  (SliderAHndl,SliderAVHndl,imageHndl,CheckHndl,ButtonHndl,...
   akvalmat,ukval,fdist,findex,fi,chnum)
%chgui: Checkbox GUI
%
%          function [findex,fi,ukval]=chgui...
%            (SliderAHndl,SliderAVHndl,imageHndl,CheckHndl,ButtonHndl,
%             akvalmat,ukval,findex,fi,chnum)
%
%          Where
%
%          SliderAHndl: Vector of the Working Picture Slider Handles
%          SliderAVHndl: Vector of the Working Picture value Display Slider Handles
%          imageHndl: Image Handle
%          CheckHndl: Vector of the Checkbox Handles
%          ButtonHndl: Vector of the Button Handles
%          akvalmat: Is the actual kansei value matrix
%          ukval: Vector of the user kansei values
%          fdist: The vector of normalised furniture distances 
%          findex: Furniture index vector (first is the best fitting)
%          fi: Furniture index pointer
%          chnum: Number of the checkbox pressed
%
%          fdist: The vector of normalised furniture distances 
%          findex: Furniture index vector (first is the best fitting)
%          fi: Furniture index pointer
%          ukval: Vector of the user kansei values
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=11,error('Invalid number of arguments!');end

min = get(CheckHndl(chnum),'Min');
max = get(CheckHndl(chnum),'Max');
value = get(CheckHndl(chnum),'Value');

colm = get(SliderAHndl(chnum),'UserData');  % color matrix

switch(value)
  case min  % release the corresponding slider
    set(SliderAHndl(chnum),'Enable','off',...  % disable the slider
      'BackgroundColor',colm(:,:,1));  % set color inactive
    ukval(chnum) = NaN;  % inactive user value
    ofindex = findex;  % save old value
    ofi = fi;  % save old value
    [fdist,findex]=kansdist(akvalmat,ukval);  % new furniture kansei distances and index
    if findex==ofindex  % there are no changes
    else  % there are changes (matrix spec.)
      fi = 1;  % reset pointer
      set(ButtonHndl(5),'Enable','off');  % disable the Previous button
      set(ButtonHndl(4),'Enable','on');  % enable the Next button
    end  % if
    if findex(fi)~=ofindex(ofi)  % the actual furniture changed
      drawfpica(imageHndl,fdist,findex,fi,SliderAVHndl,akvalmat);  % Draw the new picture
    end  % if
  case max
    akval = akvalmat(findex(fi),chnum);  % aktual kansei value of the furnitue on display
    set(SliderAHndl(chnum),'Enable','on',...  % enable the slider
      'BackgroundColor',colm(:,:,2),...  % set color active
      'Value',akval);  % set the actual value
    ukval(chnum) = akval;  % activete the user value
  otherwise
    error('Invalid checkbox value!');
end  % switch

