function drawfpica(imageHndl,fdist,findex,fi,SliderVHndl,akvalmat)
%drawfpica: Draw the working picture and adjust the value display sliders
%
%                            drawfpica(imageHndl,picnum,SliderVHndl,akvalmat)
%
%          Where
%
%          imageHndl: Image Handle
%          fdist: Is the vector of normalised distances of the user requirements and the 
%                actual furniture kansei values
%          findex: Furniture index vector (first is the best fitting)
%          fi: Furniture index pointer
%          SliderVHndl: Vector of the value Display Slider Handles
%          akvalmat: Is the actual kansei value matrix
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=6,error('Invalid number of arguments!');end

picnum = findex(fi);

fpic = imread(strcat('f',int2str(picnum),'.jpg'));  % Read Picture of the furniture

[pich,picw,x] = size(fpic);  % height, width of pictures

axesHndl = get(imageHndl,'Parent');  % get the parent axes

set(axesHndl,...
  'XLim',[0 picw], ...
  'XLimMode','manual', ...
  'YLim',[0 pich], ...
  'YLimMode','manual');  % Adjust the axes

opic = get(imageHndl,'UserData');  % The previous picture

if isempty(opic)
  set(imageHndl,'CData',fpic(:,:,:));  % Draw the picture
  set(imageHndl,'UserData',picnum);  % Set the number of the picture
else
  if opic~=picnum  % the picuture is changed
    set(imageHndl,'CData',fpic(:,:,:));  % Draw the picture
    set(imageHndl,'UserData',picnum);  % Set the number of the picture
  end  % if
end  % if

kvalnum = size(akvalmat,2);  % number of kansei values

for i=1 : 1 : kvalnum  % Adjusting the Sliders
  set(SliderVHndl(i),'Value',akvalmat(picnum,i));
end;  % for

set(SliderVHndl(kvalnum+1),'Value',1-fdist(picnum));  % Adjusting the actual fittness slider

