function [U] = fcmval(center, data, expo)
%FCMVAL FCM silmilarity values to the cluster centers of a given data
%
%	CENTER: matrix of cluster centers.
%		(Each row is a cluster center.)
%	DATA: matrix of data to be compared to cluster centers.
%		(Each row is a data point.)
%	EXPO: exponent (> 1) for the partition matrix U.
%	U: partition matrix. (U(i,j) is the MF value of data j in cluster i.)
%

% Fuzzy C-Means Clustering evaluation
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu

if nargin == 2,
  expo = 2;  % default
end;

if nargin>3 | nargin<2, error('Invalid number of arguments!');end

[cluster_n,i]=size(center);  % number of clusters

for i=1 : size(center,1)  % fill the distance matrix dist(center,data) - Eucledian distances
  for j=1 : size(data,1)
    dist(i,j) = sqrt(sum((data(j,:)-center(i,:)).^2));
  end;  % for j
end;  % for i

tmp = dist.^(-2/(expo-1));

stmp = sum(tmp);

[cn,dn] = size(tmp);  % Cluster, Data Number

for j=1 : dn

  stmpd = stmp(j);

  for i=1 : cn

    if tmp(i,j) == inf
      U(i,j) = 1;
    else
      U(i,j) = tmp(i,j)./stmpd;
    end;  % if

  end;  % for i

end;  % for j

