%FKSel: Furniture Kansei Selection
%
%                            fksel
%
%          Where
%
%          kval: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%
%          kpar: is the set of kansei parameters
%            i=0 : the number of the user types
%            i>0 : set of furniture numbers
%                  the rows are kansei identifiers
%                  1: Comfortable - Uncomfortable
%                  2: Handy/Practical - Impractical
%                  3: Complicated - Simple
%                  4: Picturesque - Harmonious
%                  5: Large - Tiny
%                  6: Heavy - Light
%                  7: Extravagant - Traditional
%                  8: Light colours - Dark colours
%                  9: Merry - Depressing
%                 10: Natural materials - Artifical materials
%                 11: Formal - Casual
%                 12: Modern - Antiquated
%                 13: Warm - Cold
%                 14: Friendly - Unfriendly
%                 15: Easy to handle - Difficult to handle
%                 16: Expensive - Cheap
%
%            The structure of the raws:
%                 Very first row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 First row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 A little bit first row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Nor the first, nor the second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 A little bit second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%                       0 (end symbol)
%                 Very second row identifier: 
%                       ordered furniture numbers, with alternating sign
%                       (same following sign means no ordering (same))
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

% Init the Kansei Values

kvalmat = gkansvm;  % (FurnitureNumber,KanseiValue,UserTypeNum)

[UDfa,VEDfa,Rfa,ustate] = gkansa(kvalmat);  % Init the parameters of the fuzzy automat
[UDmc,VEDmc,Rmc] = gkansmc(kvalmat);  % Init the parameters of the fuzzy meta control

akvalmat = gakansvl(kvalmat,ustate);  % actual kansei values (Furn,KansValue)

kansid = kanspar(-1);  % names of the kansei identifiers
kansen = kanspar(-2);  % enabling the kansei identifiers
kvalnum = size(kvalmat,2);  % number of kansei values
ukval = ones(1,kvalnum).*NaN;  % initial user values (not selected)
rkval = ones(1,kvalnum).*NaN;  % initial user required values (not selected)
[fdist,findex]=kansdist(akvalmat,ukval);  % initial furniture kansei distances and index
fi = 1;  % initial Furniture index pointer

% Init some picture parameters

borderw = 0.03;  % width of the border
textw = 0.1;  % width of the text
fonts = 2.5./size(kansid,2);  % size of fonts
contd = 1/(16-1);  % horizontal distance of control elements
sliderw = textw.*fonts;  % width of the sliders
slidervw = sliderw./3;  % width of the value display sliders
sliderbvw = sliderw.*.5;  % width of the value user state value sliders
sliderl = .5-1.5.*borderw-textw-.1.*contd;  % length of the sliders
buttonw = 3.*sliderw;  % width of the buttons
buttonl = (3./2).*buttonw;  % length of the buttons
mainbackcol = [.8 .8 .8];  % background color of the main screen
inactcol = mainbackcol+.1;  % color of the inactive sliders
actcol = mainbackcol-.1;  % color of the active sliders
slcolm(:,:,1) = inactcol;  % slider color matrix
slcolm(:,:,2) = actcol;
valcol = mainbackcol;  % color of the value display sliders
smcol(:,:,1) = mainbackcol+.1;  % middle line color of the sliders
smcol(:,:,2) = mainbackcol;  % middle line middle color of the sliders

% Main Window

MainFigNum = figure(...
	'Color',mainbackcol, ...
	'Name','Kansei Furniture Selection', ...
	'NumberTitle','off',...
	'Units','normalized', ...
	'Position',[0 0 1 1], ...
	'BackingStore','off',...
 	'NextPlot','add',...
	'Pointer','arrow',...
	'Resize','on',...
	'Visible','off');

% Working Picture

AxesPicA = axes( 'Parent',MainFigNum, ...
	'Units','normalized', ...
	'Position',[borderw./2, .5+borderw.*.5, .5-borderw.*1.5, .5-borderw.*1.5], ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'YDir','reverse', ...
	'ZColor',[0 0 0],...
	'Visible','off');

axis('image'); % image axis
PicA = image('Parent',AxesPicA);  % Working Image

% Picture for Editing

AxesPicB = axes( 'Parent',MainFigNum, ...
	'Units','normalized', ...
	'Position',[borderw./2, borderw, .5-borderw.*1.5, .5-borderw.*1.5], ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'YDir','reverse', ...
	'ZColor',[0 0 0],...
	'Visible','off');

axis('image'); % image axis
PicB = image('Parent',AxesPicB);  % Editing Image

AxesText = axes( 'Parent',MainFigNum, ...
	'Units','normalized', ...
	'Position',[.5+borderw.*.5, 1-(textw+borderw), .5-borderw.*1.5, textw], ...
	'XColor',[0 0 0], ...
	'XLim',[0 .5-borderw.*1.5], ...
	'XLimMode','manual', ...
	'YColor',[0 0 0], ...
	'YLim',[0 textw], ...
	'YLimMode','manual', ...
	'ZColor',[0 0 0],...
	'Visible','off');

ktextStr = ['text(''Parent'',AxesText,', ...
    '''Units'',''normalized'',', ...
    '''FontUnits'',''normalized'',', ...
    '''FontSize'',fonts,', ...
    '''Rotation'',90,', ...
    '''Visible'',''on'','];

for i=1 : 1 : kvalnum  % Write the names of the kansei identifiers
  eval([ktextStr, ...
      '''Position'',[(i-1).*contd,0],', ...
      '''String'',''',kansid(i,:),''')']);
end;  % for   

% Working Picture Sliders

x = .5+borderw.*.5;
y = .5+borderw.*.5;
d0 = .5-borderw.*1.5;

AxesSliderA = axes( 'Parent',MainFigNum, ...
	'Units','normalized', ...
	'Position',[x, y, d0, sliderl], ...
	'XColor',[0 0 0], ...
	'XLim',[0 1], ...
	'XLimMode','manual', ...
	'YColor',[0 0 0], ...
	'YLim',[0 1], ...
	'YLimMode','manual', ...
	'ZColor',[0 0 0],...
	'Visible','off');

line( 'Parent',AxesSliderA, ...
	'XData',[0,1], ...
	'YData',[.5,.5], ...
	'Color',smcol(:,:,1), ...
	'LineWidth',12, ...
	'Visible','on');
line( 'Parent',AxesSliderA, ...
	'XData',[0,1], ...
	'YData',[.5,.5], ...
	'Color',smcol(:,:,2), ...
	'LineWidth',3, ...
	'Visible','on');

sltextStrA = ['text(''Parent'',AxesSliderA,', ...
    '''Units'',''normalized'',', ...
    '''FontUnits'',''normalized'',', ...
    '''FontSize'',fonts./2,', ...
    '''FontWeight'',''bold'',', ...
    '''HorizontalAlignment'',''center'',', ...
    '''Visible'',''on'','];

for i=1 : 1 : kvalnum  % SliderA +,0,- symbols
  eval([sltextStrA, ...
      '''Position'',[(i-1).*contd+contd.*.45,1],', ...
      '''String'',''+'')']);
  eval([sltextStrA, ...
      '''Position'',[(i-1).*contd+contd.*.45,0],', ...
      '''String'',''-'')']);
end;  % for   

sliderStrA = ['uicontrol(''Parent'',MainFigNum,', ...
    '''Units'',''normalized'',', ...
    '''ListboxTop'',0,', ...
    '''Style'',''slider'',', ...
    '''UserData'',slcolm,', ...
    '''Min'',-1,', ...
    '''Max'',1,', ...
    '''Value'',0,'];

callbackStrA=...
  ['[fdist,findex,fi,ukval]=',...
    'slagui(SliderAHndl,SliderAVHndl,PicA,CheckHndl,ButtonHndl,',...
    'akvalmat,ukval,fdist,findex,fi,'];

x = x-sliderw./2;
d = d0.*contd;

for i=1 : 1 : kvalnum  % Generating the Sliders
  eval(['SliderA',int2str(i),'=',sliderStrA,...
      '''Position'',[x+(i-1).*d,y,sliderw,sliderl],',...
      '''BackgroundColor'',inactcol,',...
      '''Enable'',''off'',', ...
      '''Callback'',''',callbackStrA,int2str(i),');'');']);
  eval(['SliderAV',int2str(i),'=',sliderStrA,...
      '''Position'',[x-slidervw+(i-1).*d,y,slidervw,sliderl],',...
      '''BackgroundColor'',valcol,',...
      '''Enable'',''inactive'');']);
end;  % for

SliderAHndlStr = '';  % init
SliderAVHndlStr = '';  % init

for i=1 : 1 : kvalnum  % Generating the Sliders
  SliderAHndlStr = [SliderAHndlStr,'SliderA',int2str(i),','];  % collect
  SliderAVHndlStr = [SliderAVHndlStr,'SliderAV',int2str(i),','];  % collect
end;  % for

eval(['SliderAHndl=[',SliderAHndlStr,'];']);  % evaluate
eval(['SliderAVHndl=[',SliderAVHndlStr,'];']);  % evaluate

x = x-sliderw.*1.5;

SliderFV = uicontrol('Parent',MainFigNum, ...  % Slider of the actual fittness value
    'Units','normalized', ...
    'ListboxTop',0, ...
    'Style','slider', ...
    'UserData',slcolm, ...
    'Min',0, ...
    'Max',1, ...
    'Value',0,...
    'Position',[x,y,sliderbvw,sliderl],...
    'BackgroundColor',valcol,...
    'Enable','inactive');

SliderAVHndl=[SliderAVHndl,SliderFV];  % the last one is the actual fittness slider

SliderFVLab = uicontrol('Parent',MainFigNum, ...  % Actual Fittness Value Slider Label
    'Style','text', ...
    'Units','normalized', ...
    'FontUnits','normalized', ...
    'FontSize',sliderbvw.*.66, ...
    'FontWeight','normal', ...
    'ForegroundColor',[0 0 0], ...  % black
    'BackgroundColor',mainbackcol, ...
    'HorizontalAlignment','center', ...
    'Visible','on', ...
    'Position',[x,y+sliderl,sliderbvw,sliderbvw.*2.5], ...
    'String','F');

% Working Picture Checkboxes

x = .5+borderw.*.5-sliderw./2+sliderw./20;
y = .5+borderw.*.5-sliderw.*2;
d = (.5-borderw.*1.5).*contd;

checkStr = ['uicontrol(''Parent'',MainFigNum,', ...
    '''Units'',''normalized'',', ...
    '''ListboxTop'',0,', ...
    '''Style'',''checkbox'',', ...
    '''Min'',0,', ...
    '''Max'',1,', ...
    '''Value'',0,'];

callbackStrC=...
  ['[fdist,findex,fi,ukval]=',...
    'chgui(SliderAHndl,SliderAVHndl,PicA,CheckHndl,ButtonHndl,',...
    'akvalmat,ukval,fdist,findex,fi,'];

for i=1 : 1 : kvalnum  % Generating the Sliders
  if kansen(i)==1  % enabled
    eval(['Check',int2str(i),'=',checkStr,...
        '''Position'',[x+(i-1).*d,y,sliderw,sliderw],',...
        '''Enable'',''on'',', ...
        '''Callback'',''',callbackStrC,int2str(i),');'');']);
  else  % disabled
    eval(['Check',int2str(i),'=',checkStr,...
        '''Position'',[x+(i-1).*d,y,sliderw,sliderw],',...
        '''Enable'',''off'',', ...
        '''Callback'',''',callbackStrC,int2str(i),');'');']);
  end;  % if
end;  % for

CheckHndlStr = '';  % init

for i=1 : 1 : kvalnum  % Generating the Sliders
  CheckHndlStr = [CheckHndlStr,'Check',int2str(i),','];  % collect
end;  % for

eval(['CheckHndl=[',CheckHndlStr,'];']);  % evaluate

% Editing Picture Sliders

x = .5+borderw.*.5;
y = .5+borderw.*.5-sliderw.*4-sliderl-buttonw-sliderw;
d0 = .5-borderw.*1.5;

AxesSliderB = axes( 'Parent',MainFigNum, ...
	'Units','normalized', ...
	'Position',[x, y, d0, sliderl], ...
	'XColor',[0 0 0], ...
	'XLim',[0 1], ...
	'XLimMode','manual', ...
	'YColor',[0 0 0], ...
	'YLim',[0 1], ...
	'YLimMode','manual', ...
	'ZColor',[0 0 0],...
	'Visible','off');

line( 'Parent',AxesSliderB, ...
	'XData',[0,1], ...
	'YData',[.5,.5], ...
	'Color',smcol(:,:,1), ...
	'LineWidth',12, ...
	'Visible','on');
line( 'Parent',AxesSliderB, ...
	'XData',[0,1], ...
	'YData',[.5,.5], ...
	'Color',smcol(:,:,2), ...
	'LineWidth',3, ...
	'Visible','on');

sltextStrB = ['text(''Parent'',AxesSliderB,', ...
    '''Units'',''normalized'',', ...
    '''FontUnits'',''normalized'',', ...
    '''FontSize'',fonts./2,', ...
    '''FontWeight'',''bold'',', ...
    '''HorizontalAlignment'',''center'',', ...
    '''Visible'',''on'','];

for i=1 : 1 : kvalnum  % SliderB +,0,- symbols
  eval([sltextStrB, ...
      '''Position'',[(i-1).*contd+contd.*.45,1],', ...
      '''String'',''+'')']);
  eval([sltextStrB, ...
      '''Position'',[(i-1).*contd+contd.*.45,0],', ...
      '''String'',''-'')']);
end;  % for   

sliderStrB = ['uicontrol(''Parent'',MainFigNum,', ...
    '''Units'',''normalized'',', ...
    '''ListboxTop'',0,', ...
    '''Style'',''slider'',', ...
    '''UserData'',slcolm,', ...
    '''Min'',-1,', ...
    '''Max'',1,', ...
    '''Value'',0,'];

callbackStrB=...
  '[rkval]=slbgui(SliderBHndl,PicB,ButtonHndl,kansen,akvalmat,rkval,';

x = x-sliderw./2;
d = d0.*contd;

for i=1 : 1 : kvalnum  % Generating the Sliders
  eval(['SliderB',int2str(i),'=',sliderStrB,...
      '''Position'',[x+(i-1).*d,y,sliderw,sliderl],',...
      '''BackgroundColor'',inactcol,',...
      '''Enable'',''off'',', ...
      '''ButtonDownFcn'',''',callbackStrB,int2str(i),');'',',...
      '''Callback'',''',callbackStrB,int2str(i),');'');']);
  eval(['SliderBV',int2str(i),'=',sliderStrB,...
      '''Position'',[x-slidervw+(i-1).*d,y,slidervw,sliderl],',...
      '''BackgroundColor'',valcol,',...
      '''Enable'',''inactive'');']);
end;  % for

SliderBHndlStr = '';  % init
SliderBVHndlStr = '';  % init

for i=1 : 1 : kvalnum  % Generating the Slider Handles
  SliderBHndlStr = [SliderBHndlStr,'SliderB',int2str(i),','];  % collect
  SliderBVHndlStr = [SliderBVHndlStr,'SliderBV',int2str(i),','];  % collect
end;  % for

eval(['SliderBHndl=[',SliderBHndlStr,'];']);  % evaluate

callbackStrBUS=...
  ['[fdist,findex,fi,akvalmat,ustate]=slbusgui(',...
    'ButtonHndl,SliderAVHndl,SliderBVHndl,PicA,PicB,',...
    'akvalmat,kvalmat,ukval,fdist,findex,fi,ustate,'];

sliderStrBUS = ['uicontrol(''Parent'',MainFigNum,', ...
    '''Units'',''normalized'',', ...
    '''ListboxTop'',0,', ...
    '''Style'',''slider'',', ...
    '''UserData'',slcolm,', ...
    '''Min'',0,', ...
    '''Max'',1,', ...
    '''BackgroundColor'',valcol,',...
    '''Enable'',''on'','];

x = x-sliderw.*1.3;

n = size(ustate,2);  % number of the user types

for i=1 : 1 : n  % Generating the User State values sliders
  eval(['SliderBUS',int2str(i),'=',sliderStrBUS,...
      '''Value'',ustate(i),',...  % Initial value
      '''Position'',[x-(n-i).*sliderbvw,y,sliderbvw,sliderl],',...
      '''Callback'',''',callbackStrBUS,int2str(i),');'');']);
end;  % for

for i=1 : 1 : n  % Generating the User State values Slider Handles
  SliderBVHndlStr = [SliderBVHndlStr,'SliderBUS',int2str(i),','];  % add to the end
end;  % for

eval(['SliderBVHndl=[',SliderBVHndlStr,'];']);  % evaluate

SliderBVLab = [ ...  % User State values Slider Label Values
    '1'; ...
    '2'; ...
    '3'; ...
    '4'];

SliderBVStr = ['uicontrol(''Parent'',MainFigNum,', ...  % User State values Slider Labels
    '''Style'',''text'',', ...
    '''Units'',''normalized'',', ...
    '''FontUnits'',''normalized'',', ...
    '''FontSize'',sliderbvw.*.66,', ...
    '''FontWeight'',''normal'',', ...
    '''ForegroundColor'',[0 0 0],', ...  % black
    '''BackgroundColor'',mainbackcol,', ...
    '''HorizontalAlignment'',''center'',', ...
    '''Visible'',''on'','];

for i=1 : 1 : n  % Generating the User State values Slider Labels
  eval([SliderBVStr, ...
      '''Position'',',...
      '[x+sliderbvw.*.2-(n-i).*sliderbvw,y+sliderl,sliderbvw,sliderbvw.*2.5],',...
      '''String'',SliderBVLab(i))']);
  eval([SliderBVStr, ...
      '''Position'',',...
      '[x-sliderbvw.*.2-(n-i).*sliderbvw,y+sliderl+sliderbvw.*2,sliderbvw,sliderbvw.*2.5],',...
      '''String'',''S'')']);
end;  % for   

% PushButtons

x = .5+borderw.*.5-sliderw./2;
y = .5+borderw.*.5-sliderw.*4-buttonw;
d0 = .5-borderw.*1.5;

buttonStr = ['uicontrol(''Parent'',MainFigNum,', ...
    '''Units'',''normalized'',', ...
    '''ListboxTop'',0,', ...
    '''Position'',[x,y,buttonl,buttonw],', ...
    '''Style'',''pushbutton'',', ...
    '''Value'',0,'];

callbStrButt=...
  ['[fdist,findex,fi,akvalmat,rkval,ustate]=buttgui(',...
    'ButtonHndl,SliderAHndl,SliderAVHndl,SliderBHndl,SliderBVHndl,',...
    'PicA,PicB,UDfa,VEDfa,Rfa,',...
    'kansen,akvalmat,kvalmat,ukval,rkval,fdist,findex,fi,ustate,'];

eval(['ButtonCopy=',buttonStr,...
    '''Enable'',''on'',', ...
    '''String'',''Copy'',',...
    '''Callback'',''',callbStrButt,'1);'');']);

x = x+buttonl+sliderw;
eval(['ButtonReady=',buttonStr,...
    '''Enable'',''off'',', ...
    '''String'',''Ready'',',...
    '''Callback'',''',callbStrButt,'3);'');']);

x = .5+borderw.*.5+d0-buttonl;
y0 = .5+borderw.*.5-sliderw.*3-buttonw;
y = y0-sliderw;
eval(['ButtonClose=',buttonStr,...
    '''Enable'',''on'',', ...
    '''String'',''Close'',',...
    '''Callback'',''close(MainFigNum)'');']);

y = y0;
x = x-buttonl-sliderw-sliderw./2;
eval(['ButtonNext=',buttonStr,...
    '''Enable'',''on'',', ...
    '''String'',''Next'',',...
    '''Callback'',''',callbStrButt,'4);'');']);

x = x-buttonl-sliderw;
eval(['ButtonPrevious=',buttonStr,...
    '''Enable'',''off'',', ...
    '''String'',''Previous'',',...
    '''Callback'',''',callbStrButt,'5);'');']);

ButtonHndl = [ButtonCopy,NaN,ButtonReady,ButtonNext,ButtonPrevious];  % Handles

% fill the picture data, with the best fitting init value

drawfpica(PicA,fdist,findex,1,SliderAVHndl,akvalmat);
drawfpicb(PicB,findex(1),SliderBVHndl,akvalmat,ustate);

% Uncover the figure

set(MainFigNum,...
	'Visible','on');

% Draw the figure

figure(MainFigNum);  % Draw the figure

