function [akvalmat]=gakansvl(kvalmat,ustate)
%gakansvl: Calculate the actual kansei value matrix
%
%          Where
%
%          kvalmat: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%          ustate: User Type State
%
%          akvalmat: Is the actual kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=2,error('Invalid number of arguments!');end

fnum = size(kvalmat,1);  % number of furnitures
kvalnum = size(kvalmat,2);  % number of kansei values
utypenum = size(kvalmat,3);  % number of user types

if size(ustate,2)~=utypenum,error('Number of User Types and States must be the same!');end

akvalmat = zeros(fnum,kvalnum);  % initial value
average = zeros(fnum,kvalnum);  % initial value

% ustate = ustate.^p;

for i=1:1:utypenum  % go through all the user types
  akvalmat = akvalmat+ustate(i).*kvalmat(:,:,i);  % sum with weights
  average = average+kvalmat(:,:,i);  % sum with weights
end;  % for

sw = sum(ustate);  % sum of weights

if sw==0  % all zero weights
  akvalmat = average./utypenum;  % error - average instead
else
  akvalmat = akvalmat./sw;  % sum with weights
end  % if

