function [UDfa,VEDfa,Rfa,ustate] = gkansa(kvalmat)
% GKansA: Furniture Kansei Selection, generate the parameters of the fuzzy automata
%
%	Where:
%
%          kvalmat: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%
%          UDfa : Matrix of Universe of Discourses
%                  UDfa = [U1;U2;U3;U4;...;SU1;SU2;SU3;SU4;...;CU1]
%          VEDfa : Matrix of the Vague Environments
%          Rfa : Rulebases for the fuzzy automata (all the same)
%                 (voting for the values of the user states)
%          ustate: User Type State
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=1,error('Invalid number of arguments!');end

utypenum = size(kvalmat,3);  % number of user types

ustate = ones(1,utypenum).*.5;  % initial user type state

% The universes considered for the automat are:

U = [0:.01:1];	% Components of the universe of discourse

% Universe of discourse

for i=1 : 1 : utypenum.*2+1
  UDfa(i,:) = U;  % all the user type universes and the conclusion universe are the same
end  % for

% The piecewise linear scaling functions are
%  (by their break points or value):

% Assuming all the vague environments to be the same

z = 0;		% zero
m = 0.5;	% middle
l = 1;		% large

%SP =[ z,  0;
%      m,  5;
%      l,  0];

SP =[ z,  1;
      l,  1];

SF = gscnfunc(U,SP);  % NonLinear Scaling Function (linear: gsclfunc)
VE = gvagenv(U,SF);  % Vague Environment


for i=1 : 1 : utypenum.*2+1  % All the same
  VEDfa(i,:) = VE;  % all the user type and the conclusion vague environments are the same
end  % for

% The Rulebases (All the rulebases are the same)

  % NaN: (Not a number) independent from the antecedent

x = nan;  % Independency from the rule antacedent

  % The Rulebase of the fuzzy automata, voting for one of the user types
  % (All the rulebases are the same)

  % The rules are rows
  % U: Actual User States
  % SU: Level of similarity of the User Requirements and the User Types
  % CU: Conclusion User State
  % Rfa = [U1,U2,U3,U4,...,SU1,SU2,SU3,SU4,...,CU1;...]

%Rfa =     [ l, x, x, x,      l,  x,  x,  x,      l;
%            l, x, x, x,      z,  x,  x,  x,      z];

%Rfa =     [ l, x, x, x,      l,  x,  x,  x,      l;
%            m, x, x, x,      l,  x,  x,  x,      l;
%            l, x, x, x,      z,  x,  x,  x,      z;
%            z, x, x, x,      z,  x,  x,  x,      z;
%            z, l, x, x,      z,  l,  x,  x,      z;
%            z, x, l, x,      z,  x,  l,  x,      z;
%            z, x, x, l,      z,  x,  x,  l,      z];

Rfa =     [ l, x, x, x,      l,  x,  x,  x,      l;
            z, x, x, x,      z,  x,  x,  x,      z;

            z, l, x, x,      l,  l,  x,  x,      z;
            z, x, l, x,      l,  x,  l,  x,      z;
            z, x, x, l,      l,  x,  x,  l,      z;

            l, x, x, x,      z,  z,  z,  z,      l;

            z, z, z, z,      l,  z,  z,  z,      l];

