function [UDmc,VEDmc,Rmc] = gkansmc(kvalmat)
% GKansMC: Furniture Kansei Selection, generate the parameters of the fuzzy metacontrol
%
%	Where:
%
%          kvalmat: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%
%          UDmc : Matrix of Universe of Discourses
%                  UDfa = [U1;U2;U3;U4;...;CU1]
%          VEDmc : Matrix of the Vague Environments
%          Rmc : Rulebases for the fuzzy automata (all the same)
%                 (combining the different conclusions)
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=1,error('Invalid number of arguments!');end

utypenum = size(kvalmat,3);  % number of user types

% The universes considered for the automat are:

Uu = [0:.01:1];	% Components of the universe of discourse
Uc = [-1:.02:1];	% Components of the universe of discourse conclusion

% Universe of discourse

for i=1 : 1 : utypenum
  UDmc(i,:) = Uu;  % all the user type universes and the conclusion universe are the same
end  % for
UDmc(utypenum+1,:) = Uc;  % the conclusion Universe of discourse

% The piecewise linear scaling functions are
%  (by their break points or value):

% Assuming all the vague environments to be the same

nl = -1;		% negative large
z = 0;		% zero
m = 0.5;	% middle
l = 1;		% large

SPu =[ z,  0;
       m,  5;
       l,  0];

SPc =[nl,  1;
       l,  1];

SFu = gscnfunc(Uu,SPu);  % NonLinear Scaling Function (linear: gsclfunc)
SFc = gscnfunc(Uc,SPc);  % NonLinear Scaling Function (linear: gsclfunc)
VEu = gvagenv(Uu,SFu);  % Vague Environment
VEc = gvagenv(Uc,SFc);  % Vague Environment


for i=1 : 1 : utypenum  % All the same
  VEDmc(i,:) = VEu;  % all the user type vague environments are the same
end  % for
VEDmc(utypenum+1,:) = VEc;  % the conclusion vague environment

% The Rulebases (All the rulebases are the same)

  % NaN: (Not a number) independent from the antecedent

x = nan;  % Independency from the rule antacedent

  % The Rulebase of the fuzzy automata, voting for one of the user types
  % (All the rulebases are the same)

  % The rules are rows
  % U: Actual User States
  % CU: The Conclusion of the User Type (filled in runtime)
  % Rmc = [U1,U2,U3,U4,...,CUx;...]

Rmc =     [ l, z, z, z,      l;
            z, l, z, z,      l;
            z, z, l, z,      l;
            z, z, z, l,      l];

