function [ustate] = kansa(UDfa,VEDfa,Rfa,ustate,ksim)
% KansA: Furniture Kansei Selection, Calculate the new User State
%
%	Where:
%
%          UDfa : Matrix of Universe of Discourses
%                  UDfa = [U1;U2;U3;U4;...;SU1;SU2;SU3;SU4;...;CU1]
%          VEDfa : Matrix of the Vague Environments
%          Rfa : Rulebases for the fuzzy automata (all the same)
%                 (voting for the values of the user states)
%          ustate: User Type State
%          ksim: Is the vector of the kansei similarities of the actual user requirements
%                and the user types
%                (Similarities are calculated as Fuzzy C Means (FCM) membership values)
%
%          ustate: new User Type State
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=5,error('Invalid number of arguments!');end

utypenum = size(ustate,2);  % number of user types

% antecedents a single conlusion and the rulebase UDfa,VEDfa,Rfa (all the same)
% Rfa = [U1,U2,U3,U4,...,SU1,SU2,SU3,SU4,...,CU1;...]

% The observations
% x(1) = [U1,U2,U3,U4,SU1,SU2,SU3,SU4];
% x(2) = [U2,U3,U4,U1,SU2,SU3,SU4,SU1];...

for i=1 : 1 : utypenum  % go through all the user types
  for j=0 : 1 : utypenum-1  % go through all the user types
    ux(j+1) = ustate(mod(i+j-1,utypenum)+1);
    kx(j+1) = ksim(mod(i+j-1,utypenum)+1);
  end  % for
  x(i,:) = [ux,kx];  % observation
end  % for

% Crisp input, crisp output with interpolation in vague environment

for i=1 : 1 : utypenum  % go through all the user types
  ustate(i) = vagconcl(UDfa,VEDfa,Rfa,2,x(i,:));
end  % for

