function [dist,index]=kansdist(akvalmat,ukval)
%kansdist: Calculate the kansei distances matrix
%
%                            [dist]=kansdist(akvalmat,ukval)
%
%          Where
%
%          akvalmat: Is the actual kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%
%          ukval: Is the user kansei value vector
%
%          dist: Is the vector of normalised distances of the user requirements and the 
%                actual furniture kansei values
%
%          index: index for ascending order of the distances
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=2,error('Invalid number of arguments!');end
if size(akvalmat,2)~=size(ukval,2),...
    error('The number of requirements and objects must be same!');end

[x,y] = size(akvalmat);

k = 1;  % counter
for i=1:1:y  % go through all the kansei values
  if ~isnan(ukval(i))
    ms(1:x,k) = ukval(i);
    as(:,k) = akvalmat(:,i);
    k = k+1;
  end;  % if
end;  % for

if k==1  % no kansei values selected
  ukval = zeros(1,size(akvalmat,2));  % initial user values (all zero)
  for i=1:1:x  % go through all the furnitures
    m(i,:) = ukval;
  end;  % for
  d = akvalmat-m;  % difference
else
  d = as-ms;  % difference
end;  % if

d = d.^2;  % square
s = sum(d,2);  % sum of distances

dist = s.^.5;  % square root - Eucledian distance

dist = dist./max(dist);  % normalisation

[t,index] = sort(dist);  % index for ascending order

