function [akvalmat] = kansmc(UDmc,VEDmc,Rmc,kvalmat,ustate)
% KansA: Furniture Kansei Selection, combining the different conclusions
%
%	Where:
%
%          UDmc : Matrix of Universe of Discourses
%                  UDfa = [U1;U2;U3;U4;...;CU1]
%          VEDmc : Matrix of the Vague Environments
%          Rmc : Rulebases for the fuzzy automata (all the same)
%                 (combining the different conclusions)
%          kvalmat: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%          ustate: User Type State
%
%          akvalmat: Is the actual kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=5,error('Invalid number of arguments!');end

fnum = size(kvalmat,1);  % number of furnitures
kvalnum = size(kvalmat,2);  % number of kansei values
utypenum = size(kvalmat,3);  % number of user types

% antecedents a single conlusion and the rulebase UDmc,VEDmc,Rmc (all the same)
% Rmc = [U1,U2,U3,U4,...,CUx;...]
% Rmc = [ l, z, z, z,    CU1;
%         z, l, z, z,    CU2;
%         z, z, l, z,    CU3;
%         z, z, z, l,    CU4];

% The observations
% x = [U1,U2,U3,U4];

x = ustate;  % observation (all the same)

for f=1 : 1 : fnum  % go through all furnitures
  for k=1 : 1 : kvalnum  % go through all kansei values
    for i=1 : 1 : utypenum  % modify the rulebase by the actual usertype conclusions
      Rmc(i,utypenum+1) = kvalmat(f,k,i);
    end  % for
    akvalmat(f,k) = vagconcl(UDmc,VEDmc,Rmc,2,x);  % interpolation in vague environment
  end  % for
end  % for

