function [ksim]=kanssim(kvalmat,ukval,fnum)
%kanssim: Calculate the kansei similarities matrix
%
%                            [ksim,index]=kanssim(kvalmat,ukval,fnum)
%
%          Where
%
%          kvalmat: Is the kansei value matrix, where 
%                  the 1st dimension characterises the furnitures
%                  the 2nd dimension characterises the kansei values
%                  the 3nd dimension characterises the user type
%
%          ukval: Is the user kansei value vector (NaN elements are not defined)
%
%          fnum: Is the number of the actual (edited) furniture
%
%          ksim: Is the vector of the kansei similarities of the actual user requirements
%                and the user types
%                (Similarities are calculated as Fuzzy C Means (FCM) membership values)
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=3,error('Invalid number of arguments!');end
if size(kvalmat,2)~=size(ukval,2),...
    error('The number of requirements and objects must be same!');end

[x,y,z] = size(kvalmat);

k = 1;  % counter
for i=1:1:y  % go through all the kansei values
  if ~isnan(ukval(i))
    uks(k) = ukval(i);
    for j=1:1:z
      kvs(j,k) = kvalmat(fnum,i,j);  % the rows are the user types
    end  % for
    k = k+1;
  end;  % if
end;  % for

if k==1,error('No user kansei values set!');end

%function [U] = fcmval(center, data, expo)
%FCMVAL FCM silmilarity values to the cluster centers of a given data
%
%	CENTER: matrix of cluster centers.
%		(Each row is a cluster center.)
%	DATA: matrix of data to be compared to cluster centers.
%		(Each row is a data point.)
%	EXPO: exponent (> 1) for the partition matrix U.
%	U: partition matrix. (U(i,j) is the MF value of data j in cluster i.)

ksim = fcmval(kvs,uks,2);  % Calculate the similarity to the different user types
