function [dist]=ruledist(u,ve,r,x)
%RULEDIST: Calculate the distances of the observation from the rule antecedents
%
%                            [DIST]=vagdist(U,VE,R,X)
%
%          Where DIST is the distance from the rule antecedents,
%          U is the universe, VE is the vague environment, 
%          (the rows are the dimensions)
%          R is the rulebase, X is the observation.
%
%          Rulebase:
%
%            R1 | a1 a2 a3 ... am -> b
%            R2 | a1 a2 a3 ... am -> b
%            R2 | a1 a2 a3 ... am -> b
%             .
%             .
%             .
%            Rn | a1 a2 a3 ... am -> b
%
%            If ai=NaN then the rule antecedent ai is not exists
%

% Fuzzy Inference by Interpolation in Vague Environment toolbox for MATLAB
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin ~= 4,error('Invalid number of arguments!');end

if length(u) ~= length(ve)
  error('Input arguments must be the same length!');
end

[n,m] = size(r);

for i=1 : n   % Go through all rules

  dm = vagdist(u(1:m-1,:),ve(1:m-1,:),r(i,1:m-1),x);

  dist(i) = sqrt(sum(dm.^2)); % Euclidean distance

end % for i

