function [rkval]=slbgui(SliderBHndl,imageHndl,ButtonHndl,kansen,akvalmat,rkval,slnum)
%slbgui: Editing Picture Sliders GUI
%
%          [rkval]=slbgui(SliderBHndl,imageHndl,ButtonHndl,kansen,akvalmat,rkval,slnum)
%
%          Where
%
%          SliderBHndl: Vector of the Editing Picture Slider Handles
%          imageHndl: Image Handle
%          ButtonHndl: Vector of the Button Handles
%          kansen: enabling the kansei identifiers (1: enable, 0:disable)
%          akvalmat: Is the actual kansei value matrix
%          rkval: Vector of the user required kansei values
%          slnum: Number of the slider activated 
%
%          rkval: Vector of the user required kansei values
%

% Fuzzy Kansei Systems (furniture selection)
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs

if nargin~=7,error('Invalid number of arguments!');end

kvalnum = size(akvalmat,2);  % number of kansei values

if strcmp(get(SliderBHndl(slnum),'Enable'),'on')  % The pressed slider is already selected
  rkval(slnum) = get(SliderBHndl(slnum),'Value');  % get the new user required value
else
  if kansen(slnum)==1  % the kansei feature is enabled
    colm = get(SliderBHndl(slnum),'UserData');  % color matrix
    set(SliderBHndl(slnum),'Enable','on',...  % Enable the pressed slider
      'BackgroundColor',colm(:,:,2));  % set color active
    picnum = get(imageHndl,'UserData');  % Editing picture
    set(SliderBHndl(slnum),'Value',akvalmat(picnum,slnum));  % initial value
    if strcmp(get(ButtonHndl(3),'Enable'),'off')  % The ready button is off' - start editing
      set(ButtonHndl(3),'Enable','on');  % enable the Ready button
      set(ButtonHndl(1),'String','Cancel');  % change Copy to Cancel button
      rkval = ones(1,kvalnum).*NaN;  % set initial user required values (not selected)
    end;  % if
  end  % if
end  % if

