function [val]=valvag(u,ve,vp)
%VALVAG:  Value of a vague point VP
%
%                            [VAL]=valvag(U,VE,VP)
%
%          Where VAL is the value to find,
%          U is the universe, VE is the vague invironment,
%          VP is the vague point.
%

% Fuzzy Inference by Interpolation in Vague Environment toolbox for MATLAB
% By Szilveszter Kovacs
% e-mail: szkszilv@gold.uni-miskolc.hu
%   Copyright (c) by Szilveszter Kovacs


if nargin ~= 3,error('Invalid number of arguments!');end

if length(u) ~= length(ve)
  error('Input arguments must be the same length!');
end

[m,n] = size(u);

for k=1 : m

  if vp(k) < 0 | vp(k) > ve(k,n)
    error('The points are out of range!');
  end

  [dm,i] = min(abs(ve(k,:)-vp(k)));
                                   % i is the index of the min distance from vp

  % The distance in vague environment

  val(k) = u(k,i);

end % for k

